@@ -2,9 +2,9 @@
 
 char const *hashmap_textOf(register HashMap *map, char const *key)
 {
-    unsigned idx = hm_find_idx(map, key, ANY);
+    size_t idx = hm_find_idx(map, key, ANY);
 
-    return (idx == FAILED) ?
+    return (idx == UFAILED) ?
                 ""
             :
                 (char const *)hashitem_value(map->d_map[idx]);
